@@ -18,10 +18,10 @@
 
 
 import kb
-from arith import Number, Arith
+from metanl import Number, Arith, Noun, Word, Verb
 from thing import Thing
 from state import State
-from prop import Fact, Fact
+from prop import Fact
 from time import Time, Instant, Duration, Finish, During, Coincide, MinComStart, MaxComEnd, Intersection
 from rule import Rule
 from utils import change_now
