@@ -15,42 +15,40 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with ln.  If not, see <http://www.gnu.org/licenses/>.
-
+'''
+we can use classes:
+    as cls (and as var within rules)
+        in rules (prems and cons) and atomic facts
+                as subject in fact
+                as object in a predicate in fact
+'''
 import clips
-# import logging
 from nl.log import logger
-from nl.utils import register, Name, varpat, subclasses
-from nl.arith import Number
+from nl import utils
+from nl.metanl import Namable, Word
 from nl.time import Time, Instant
 from nl.thing import Thing
 from nl.state import State
 
 _m = []
 
-class Fact(Name):
+class Fact(Namable):
     """
     """
-    _v_clips_class = clips.FindClass('Fact')
-
     def __init__(self, subj, pred, time=Instant('now'), truth=1):
         self.truth = truth
-        if isinstance(subj, Thing):
-            self.subject = subj
-        elif isinstance(subj, str):
-            if varpat.match(subj):
+        if isinstance(subj, str):
+            if utils.varpat.match(subj):
                 self.subject = Thing(subj)
             else:
                 from nl import kb
                 self.subject = kb.ask_obj(Thing(subj))[0]
         else:
-            pass # raise exception
-        if isinstance(pred, State):
-            self.predicate = pred
-        elif isinstance(pred, str) and varpat.match(pred):
+            self.subject = subj
+        if isinstance(pred, str):
             self.predicate = State(pred)
         else:
-            pass # raise exception
-        logger.info(str(issubclass(type(time),Time)))
+            self.predicate = pred
         if isinstance(time, Time):
             self.time = time
         else:
@@ -68,7 +66,11 @@ class Fact(Name):
     def from_clips(cls, instance):
         if not isinstance(instance, clips._clips_wrap.Instance):
             instance = clips.FindInstance(instance)
-        s = Name.from_clips(instance.GetSlot('subject'))
+        s = instance.GetSlot('subject')
+        if isinstance(instance, clips._clips_wrap.Class):
+            s = Word.from_clips(s)
+        else:
+            s = Namable.from_clips(s)
         p = State.from_clips(instance.GetSlot('predicate'))
         t = Time.from_clips(instance.GetSlot('time'))
         truth = instance.GetSlot('truth')
@@ -86,7 +88,8 @@ class Fact(Name):
         return (instance-set templates, instance-set queries)
         """
         templs.append((newvar, self.__class__.__name__))
-        s = self.subject.get_isc(templs, queries, vrs)
+        isc_meth = getattr(self.subject, 'get_isc_cls', self.subject.get_isc)
+        s = isc_meth(templs, queries, vrs)
         queries.append('(eq ?%s:subject %s)' % (newvar, s))
         p = self.predicate.get_isc(templs, queries, vrs)
         queries.append('(eq ?%s:predicate %s)' % (newvar, p))
@@ -100,8 +103,11 @@ class Fact(Name):
         put proposition in clips as a conditional element of a rule
         """
         ce = '(logical (object (is-a Fact) (subject %s) (predicate %s) (time %s) (truth %s)))'
-        return ce % (self.subject.get_slot_constraint(vrs),
-                     self.predicate.get_slot_constraint(vrs),
+        constraint_meth = getattr(self.subject, 'clsput', self.subject.get_slot_constraint)
+        s = constraint_meth(vrs)
+        constraint_meth = getattr(self.predicate, 'clsput', self.predicate.get_slot_constraint)
+        p = constraint_meth(vrs)
+        return ce % (s, p,
                      self.time.get_slot_constraint(vrs),
                      self.truth)
 
@@ -112,9 +118,10 @@ class Fact(Name):
         """
         if vrs is None:
             vrs = {}
-        s = self.subject.put(vrs)
-        p = self.predicate.put(vrs)
+        put_meth = getattr(self.subject, 'clsput', self.subject.put)
+        s = put_meth(vrs)
+        put_meth = getattr(self.predicate, 'clsput', self.predicate.put)
+        p = put_meth(vrs)
         t = self.time.put(vrs)
         return '(add-prop %s %s %s %s)' % (s, p, t, self.truth)
 
-register('Fact', Fact)
