@@ -16,10 +16,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with ln.  If not, see <http://www.gnu.org/licenses/>.
 
+from nl.log import logger
 import uuid
-from nl.utils import Name
+from nl.metanl import Namable
 
-class Rule(Name):
+class Rule(Namable):
     """
     """
     def __init__(self, prems, cons):
